@@ -12,14 +12,15 @@ def main():
     parser.add_argument('--end', '-e', dest='end', type=str, action='store', help='End position, required in genome mode')
     parser.add_argument('--mode', '-m', dest='mode', action='store', choices=['genome', 'gene', 'mixed'], required=True, help='Alignment mode')
     parser.add_argument('--compress', '-c', dest='compress', action='store_true', help='Compress identical sequences')
+    parser.add_argument('--parallel', '-p', dest='para', action='store_true', help='Enable parallelization? (Runs faster)')
     args = parser.parse_args()
 
     if args.mode == 'genome':
-        genome_mode(args.reference, args.reads, args.start, args.end, args.compress)
+        genome_mode(args.reference, args.reads, args.start, args.end, args.compress, args.para)
     elif args.mode == 'gene':
         gene_mode(args.reference, args.reads, args.compress)
     else:
-        mixed_mode(args.reference, args.reads, args.compress)
+        mixed_mode(args.reference, args.reads, args.compress, args.para)
 
 if __name__ == '__main__':
     exit(main())
